@@ -2,7 +2,7 @@
 
 use strict;
 use warnings;
-use MyInstall;
+use MyAppInstall;
 use File::Temp qw(tempdir);
 
 my $template_dir = "templates/";
@@ -10,7 +10,7 @@ my $install_dir  = tempdir();
 print "Templates are in directory $template_dir\n";
 print "Installing into temporary directory $install_dir\n";
 
-MyInstall->install(
+MyAppInstall->install(
     install_dir => $install_dir,
     template_dir => $template_dir,
     data => { baz => 'quux' },
